@@ -42,7 +42,8 @@
 
 #include <nm-vpn-plugin-utils.h>
 
-#include <gnome-keyring.h>
+#define SECRET_API_SUBJECT_TO_CHANGE
+#include <libsecret/secret.h>
 
 #include "src/nm-openconnect-service.h"
 
@@ -94,20 +95,17 @@
 #include <openssl/ui.h>
 #endif
 
-static const GnomeKeyringPasswordSchema OPENCONNECT_SCHEMA_DEF = {
-  GNOME_KEYRING_ITEM_GENERIC_SECRET,
-  {
-    {"vpn_uuid", GNOME_KEYRING_ATTRIBUTE_TYPE_STRING},
-    {"auth_id", GNOME_KEYRING_ATTRIBUTE_TYPE_STRING},
-    {"label", GNOME_KEYRING_ATTRIBUTE_TYPE_STRING},
-    {NULL, 0}
-  }
+static const SecretSchema openconnect_secret_schema = {
+	"org.freedesktop.NetworkManager.Connection.Openconnect",
+	SECRET_SCHEMA_DONT_MATCH_NAME,
+	{
+		{ "vpn_uuid", SECRET_SCHEMA_ATTRIBUTE_STRING },
+		{ "auth_id", SECRET_SCHEMA_ATTRIBUTE_STRING },
+		{ "label", SECRET_SCHEMA_ATTRIBUTE_STRING },
+		{ NULL, 0 },
+	}
 };
 
-const GnomeKeyringPasswordSchema *OPENCONNECT_SCHEMA = &OPENCONNECT_SCHEMA_DEF;
-
-static void got_keyring_pw(GnomeKeyringResult result, const char *string, gpointer data);
-
 static char *lasthost;
 
 typedef struct vpnhost {
@@ -126,7 +124,7 @@ enum certificate_response{
 };
 
 /* This struct holds all information we need to add a password to
- * gnome-keyring. It’s used in success_passwords. */
+ * the secret store. It’s used in success_passwords. */
 struct keyring_password {
 	char *description;
 	char *password;
@@ -152,16 +150,14 @@ static void keyring_password_free(gpointer data)
 static void keyring_store_passwords(gpointer key, gpointer value, gpointer user_data)
 {
 	struct keyring_password *kp = (struct keyring_password*)value;
-	gnome_keyring_store_password_sync (
-			OPENCONNECT_SCHEMA,
-			GNOME_KEYRING_DEFAULT,
-			kp->description,
-			kp->password,
-			"vpn_uuid", kp->vpn_uuid,
-			"auth_id", kp->auth_id,
-			"label", kp->label,
-			NULL
-			);
+
+	secret_password_store_sync (&openconnect_secret_schema, NULL,
+	                            kp->description, kp->password,
+	                            NULL, NULL,
+	                            "vpn_uuid", kp->vpn_uuid,
+	                            "auth_id", kp->auth_id,
+	                            "label", kp->label,
+	                            NULL);
 }
 
 
@@ -193,25 +189,19 @@ typedef struct auth_ui_data {
 
 	int form_grabbed;
 	GQueue *form_entries; /* modified from worker thread */
-	GMutex *form_mutex;
+	GMutex form_mutex;
 
-	GCond *form_retval_changed;
+	GCond form_retval_changed;
 	gpointer form_retval;
 
-	GCond *form_shown_changed;
+	GCond form_shown_changed;
 	gboolean form_shown;
 
 	gboolean newgroup;
 	gboolean group_set;
 
-	GCond *cert_response_changed;
+	GCond cert_response_changed;
 	enum certificate_response cert_response;
-
-#if GLIB_CHECK_VERSION (2,31,0)
-	/* Ick. FFS, why does glib deprecate stuff so quickly? */
-	GCond _gconds[3];
-	GMutex _gmutex;
-#endif
 } auth_ui_data;
 
 enum {
@@ -237,11 +227,7 @@ static void ssl_box_add_error(auth_ui_data *ui_data, const char *msg)
 {
 	GtkWidget *hbox, *text, *image;
 
-#if GTK_CHECK_VERSION(3,1,6)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
-#else
-	hbox = gtk_hbox_new(FALSE, 8);
-#endif
 	gtk_box_pack_start(GTK_BOX(ui_data->ssl_box), hbox, FALSE, FALSE, 0);
 
 	image = gtk_image_new_from_icon_name("dialog-error",
@@ -258,11 +244,7 @@ static void ssl_box_add_notice(auth_ui_data *ui_data, const char *msg)
 {
 	GtkWidget *hbox, *text, *image;
 
-#if GTK_CHECK_VERSION(3,1,6)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
-#else
-	hbox = gtk_hbox_new(FALSE, 8);
-#endif
 	gtk_box_pack_start(GTK_BOX(ui_data->ssl_box), hbox, FALSE, FALSE, 0);
 
 	image = gtk_image_new_from_icon_name("dialog-warning",
@@ -303,7 +285,7 @@ static void ssl_box_clear(auth_ui_data *ui_data)
 typedef struct ui_fragment_data {
 	GtkWidget *widget;
 	GtkWidget *entry;
-	gpointer find_request;
+	GCancellable *cancel;
 	auth_ui_data *ui_data;
 #ifdef OPENCONNECT_OPENSSL
 	UI_STRING *uis;
@@ -429,11 +411,7 @@ static gboolean ui_write_prompt (ui_fragment_data *data)
 		visible = (data->opt->type == OC_FORM_OPT_TEXT);
 	}
 
-#if GTK_CHECK_VERSION(3,1,6)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-	hbox = gtk_hbox_new(FALSE, 0);
-#endif
 	gtk_box_pack_start(GTK_BOX(data->ui_data->ssl_box), hbox, FALSE, FALSE, 0);
 
 	text = gtk_label_new(label);
@@ -471,11 +449,7 @@ static gboolean ui_add_select (ui_fragment_data *data)
 	struct oc_form_opt_select *sopt = (void *)data->opt;
 	int i, user_selection = -1;
 
-#if GTK_CHECK_VERSION(3,1,6)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-	hbox = gtk_hbox_new(FALSE, 0);
-#endif
 	gtk_box_pack_start(GTK_BOX(data->ui_data->ssl_box), hbox, FALSE, FALSE, 0);
 
 	text = gtk_label_new(data->opt->label);
@@ -515,11 +489,11 @@ static gboolean ui_show (auth_ui_data *ui_data)
 	gtk_widget_hide (ui_data->getting_form_label);
 	gtk_widget_show_all (ui_data->ssl_box);
 	gtk_widget_set_sensitive (ui_data->cancel_button, TRUE);
-	g_mutex_lock (ui_data->form_mutex);
+	g_mutex_lock (&ui_data->form_mutex);
 	evaluate_login_visibility(ui_data);
 	ui_data->form_shown = TRUE;
-	g_cond_signal (ui_data->form_shown_changed);
-	g_mutex_unlock (ui_data->form_mutex);
+	g_cond_signal (&ui_data->form_shown_changed);
+	g_mutex_unlock (&ui_data->form_mutex);
 
 	return FALSE;
 }
@@ -563,9 +537,9 @@ static int ui_write(UI *ui, UI_STRING *uis)
 
 	case UIT_PROMPT:
 	case UIT_VERIFY:
-		g_mutex_lock (ui_data->form_mutex);
+		g_mutex_lock (&ui_data->form_mutex);
 		g_queue_push_head(ui_data->form_entries, data);
-		g_mutex_unlock (ui_data->form_mutex);
+		g_mutex_unlock (&ui_data->form_mutex);
 
 		g_idle_add ((GSourceFunc)ui_write_prompt, data);
 		break;
@@ -588,17 +562,17 @@ static int ui_flush(UI* ui)
 	ui_data = UI_get0_user_data(ui);
 
 	g_idle_add((GSourceFunc)ui_show, ui_data);
-	g_mutex_lock(ui_data->form_mutex);
+	g_mutex_lock(&ui_data->form_mutex);
 	/* wait for ui to show */
 	while (!ui_data->form_shown) {
-		g_cond_wait(ui_data->form_shown_changed, ui_data->form_mutex);
+		g_cond_wait(&ui_data->form_shown_changed, &ui_data->form_mutex);
 	}
 	ui_data->form_shown = FALSE;
 
 	if (!ui_data->cancelled) {
 		/* wait for form submission or cancel */
 		while (!ui_data->form_retval) {
-			g_cond_wait(ui_data->form_retval_changed, ui_data->form_mutex);
+			g_cond_wait(&ui_data->form_retval_changed, &ui_data->form_mutex);
 		}
 		response = GPOINTER_TO_INT (ui_data->form_retval);
 		ui_data->form_retval = NULL;
@@ -612,13 +586,13 @@ static int ui_flush(UI* ui)
 		if (data->entry_text) {
 			UI_set_result(ui, data->uis, data->entry_text);
 		}
-		if (data->find_request) {
-			gnome_keyring_cancel_request(data->find_request);
+		if (data->cancel) {
+			g_cancellable_cancel(data->cancel);
 		}
 		g_slice_free (ui_fragment_data, data);
 	}
 	ui_data->form_grabbed = 0;
-	g_mutex_unlock(ui_data->form_mutex);
+	g_mutex_unlock(&ui_data->form_mutex);
 
 	/* -1 = cancel,
 	 *  0 = failure,
@@ -657,12 +631,24 @@ static char *find_form_answer(GHashTable *secrets, struct oc_auth_form *form,
 	return result;
 }
 
-/* Callback which is called when we got a reply from gnome-keyring for any
+/* Callback which is called when we got a reply from the secret store for any
  * password field. Updates the contents of the password field unless the user
  * entered anything in the meantime. */
-static void got_keyring_pw(GnomeKeyringResult result, const char *string, gpointer userdata)
+static void got_keyring_pw(GObject *object, GAsyncResult *result, gpointer userdata)
 {
 	ui_fragment_data *data = (ui_fragment_data*)userdata;
+	GList *list;
+	SecretItem *item;
+	SecretValue *value = NULL;
+	const char *string = NULL;
+
+	list = secret_service_search_finish (SECRET_SERVICE (object), result, NULL);
+	if (list != NULL) {
+		item = list->data;
+		value = secret_item_get_secret (item);
+		string = secret_value_get (value, NULL);
+	}
+
 	if (string != NULL) {
 		if (data->entry) {
 			if (!g_ascii_strcasecmp("",
@@ -675,9 +661,13 @@ static void got_keyring_pw(GnomeKeyringResult result, const char *string, gpoint
 			data->entry_text = g_strdup (string);
 	}
 
-	/* zero the find request so that we don’t attempt to cancel it when
+	if (value)
+		secret_value_unref (value);
+	g_list_free_full (list, g_object_unref);
+
+	/* zero the cancellable so that we don’t attempt to cancel it when
 	 * closing the dialog */
-	data->find_request = NULL;
+	g_clear_object (&data->cancel);
 }
 
 /* This part for processing forms from openconnect directly, rather than
@@ -688,13 +678,13 @@ static gboolean ui_form (struct oc_auth_form *form)
 	auth_ui_data *ui_data = _ui_data; /* FIXME global */
 	struct oc_form_opt *opt;
 
-	g_mutex_lock(ui_data->form_mutex);
+	g_mutex_lock(&ui_data->form_mutex);
 	while (!g_queue_is_empty (ui_data->form_entries)) {
 		ui_fragment_data *data;
 		data = g_queue_pop_tail (ui_data->form_entries);
 		g_slice_free (ui_fragment_data, data);
 	}
-	g_mutex_unlock(ui_data->form_mutex);
+	g_mutex_unlock(&ui_data->form_mutex);
 
 	if (form->banner)
 		ssl_box_add_info(ui_data, form->banner);
@@ -716,33 +706,34 @@ static gboolean ui_form (struct oc_auth_form *form)
 		
 		if (opt->type == OC_FORM_OPT_PASSWORD ||
 		    opt->type == OC_FORM_OPT_TEXT) {
-			g_mutex_lock (ui_data->form_mutex);
+			g_mutex_lock (&ui_data->form_mutex);
 			g_queue_push_head(ui_data->form_entries, data);
-			g_mutex_unlock (ui_data->form_mutex);
+			g_mutex_unlock (&ui_data->form_mutex);
 			if (opt->type != OC_FORM_OPT_PASSWORD) {
 				data->entry_text = g_strdup (find_form_answer(ui_data->secrets,
 									      form, opt));
 				if (!data->entry_text)
 					data->entry_text = g_strdup (opt->value);
 			} else {
-				data->find_request = gnome_keyring_find_password(
-						OPENCONNECT_SCHEMA,
-						got_keyring_pw,
-						data,
-						NULL,
-						"vpn_uuid", ui_data->vpn_uuid,
-						"auth_id", form->auth_id,
-						"label", data->opt->name,
-						NULL
-						);
-			}
+				GHashTable *attrs;
 
+				data->cancel = g_cancellable_new ();
+				attrs = secret_attributes_build (&openconnect_secret_schema,
+				                                 "vpn_uuid", ui_data->vpn_uuid,
+				                                 "auth_id", form->auth_id,
+				                                 "label", data->opt->name,
+				                                 NULL);
+				secret_service_search (NULL, &openconnect_secret_schema, attrs,
+				                       SECRET_SEARCH_ALL | SECRET_SEARCH_UNLOCK | SECRET_SEARCH_LOAD_SECRETS,
+				                       data->cancel, got_keyring_pw, data);
+				g_hash_table_unref (attrs);
+			}
 
 			ui_write_prompt(data);
 		} else if (opt->type == OC_FORM_OPT_SELECT) {
-			g_mutex_lock (ui_data->form_mutex);
+			g_mutex_lock (&ui_data->form_mutex);
 			g_queue_push_head(ui_data->form_entries, data);
-			g_mutex_unlock (ui_data->form_mutex);
+			g_mutex_unlock (&ui_data->form_mutex);
 			data->entry_text = g_strdup (find_form_answer(ui_data->secrets,
 								      form, opt));
 
@@ -806,17 +797,17 @@ static int nm_process_auth_form (void *cbdata, struct oc_auth_form *form)
 	ui_data->newgroup = FALSE;
 	g_idle_add((GSourceFunc)ui_form, form);
 
-	g_mutex_lock(ui_data->form_mutex);
+	g_mutex_lock(&ui_data->form_mutex);
 	/* wait for ui to show */
 	while (!ui_data->form_shown) {
-		g_cond_wait(ui_data->form_shown_changed, ui_data->form_mutex);
+		g_cond_wait(&ui_data->form_shown_changed, &ui_data->form_mutex);
 	}
 	ui_data->form_shown = FALSE;
 
 	if (!ui_data->cancelled) {
 		/* wait for form submission or cancel */
 		while (!ui_data->form_retval) {
-			g_cond_wait(ui_data->form_retval_changed, ui_data->form_mutex);
+			g_cond_wait(&ui_data->form_retval_changed, &ui_data->form_mutex);
 		}
 		response = GPOINTER_TO_INT (ui_data->form_retval);
 		ui_data->form_retval = NULL;
@@ -829,8 +820,8 @@ static int nm_process_auth_form (void *cbdata, struct oc_auth_form *form)
 			ui_fragment_data *data;
 			data = g_queue_pop_tail (ui_data->form_entries);
 
-			if (data->find_request)
-				gnome_keyring_cancel_request(data->find_request);
+			if (data->cancel)
+				g_cancellable_cancel(data->cancel);
 
 			if (data->entry_text) {
 				data->opt->value = g_strdup (data->entry_text);
@@ -844,7 +835,7 @@ static int nm_process_auth_form (void *cbdata, struct oc_auth_form *form)
 				}
 
 				if (data->opt->type == OC_FORM_OPT_PASSWORD) {
-					/* store the password in gnome-keyring */
+					/* store the password in the secret store */
 					//int result;
 					struct keyring_password *kp = g_new(struct keyring_password, 1);
 					kp->description = g_strdup_printf(_("OpenConnect: %s: %s:%s"), ui_data->vpn_name, form->auth_id, data->opt->name);
@@ -862,8 +853,8 @@ static int nm_process_auth_form (void *cbdata, struct oc_auth_form *form)
 	}
 
 	ui_data->form_grabbed = 0;
-	g_mutex_unlock(ui_data->form_mutex);
-	
+	g_mutex_unlock(&ui_data->form_mutex);
+
 	if (response == AUTH_DIALOG_RESPONSE_LOGIN) {
 		if (ui_data->newgroup)
 			return OC_FORM_RESULT_NEWGROUP;
@@ -952,13 +943,13 @@ static gboolean user_validate_cert(cert_data *data)
 
 	gtk_widget_destroy(dlg);
 
-	g_mutex_lock (ui_data->form_mutex);
+	g_mutex_lock (&ui_data->form_mutex);
 	if (result == GTK_RESPONSE_OK)
 		data->ui_data->cert_response = CERT_ACCEPTED;
 	else
 		data->ui_data->cert_response = CERT_DENIED;
-	g_cond_signal (ui_data->cert_response_changed);
-	g_mutex_unlock (ui_data->form_mutex);
+	g_cond_signal (&ui_data->cert_response_changed);
+	g_mutex_unlock (&ui_data->form_mutex);
 
 	return FALSE;
 }
@@ -997,14 +988,14 @@ static int validate_peer_cert(void *cbdata,
 	data->peer_cert = peer_cert;
 	data->reason = reason;
 
-	g_mutex_lock(ui_data->form_mutex);
+	g_mutex_lock(&ui_data->form_mutex);
 
 	ui_data->cert_response = CERT_USER_NOT_READY;
 	g_idle_add((GSourceFunc)user_validate_cert, data);
 
 	/* wait for user to accept or cancel */
 	while (ui_data->cert_response == CERT_USER_NOT_READY) {
-		g_cond_wait(ui_data->cert_response_changed, ui_data->form_mutex);
+		g_cond_wait(&ui_data->cert_response_changed, &ui_data->form_mutex);
 	}
 	if (ui_data->cert_response == CERT_ACCEPTED) {
 		if (certs_data) {
@@ -1019,7 +1010,7 @@ static int validate_peer_cert(void *cbdata,
 	} else {
 		ret = -EINVAL;
 	}
-	g_mutex_unlock (ui_data->form_mutex);
+	g_mutex_unlock (&ui_data->form_mutex);
 
 	g_slice_free(cert_data, data);
 
@@ -1260,23 +1251,6 @@ static void autocon_toggled(GtkWidget *widget)
 	g_hash_table_insert (ui_data->secrets, g_strdup ("autoconnect"), enabled);
 }
 
-/* gnome_keyring_delete_password() only deletes one matching password, so
-   keep doing it until it doesn't succeed. The ui_data is essentially
-   permanent anyway so no need to worry about its lifetime. */
-static void delete_next_password(GnomeKeyringResult result, gpointer data)
-{
-	auth_ui_data *ui_data = data;
-
-	if (result == GNOME_KEYRING_RESULT_OK) {
-		gnome_keyring_delete_password(OPENCONNECT_SCHEMA,
-					      delete_next_password,
-					      ui_data, NULL,
-					      "vpn_uuid", ui_data->vpn_uuid,
-					      NULL);
-	}		
-		
-}
-
 static void savepass_toggled(GtkWidget *widget)
 {
 	auth_ui_data *ui_data = _ui_data; /* FIXME global */
@@ -1286,11 +1260,9 @@ static void savepass_toggled(GtkWidget *widget)
 		enabled = g_strdup ("yes");
 	else {
 		enabled = g_strdup ("no");
-		gnome_keyring_delete_password(OPENCONNECT_SCHEMA,
-					      delete_next_password,
-					      ui_data, NULL,
-					      "vpn_uuid", ui_data->vpn_uuid,
-					      NULL);
+		secret_password_clear (&openconnect_secret_schema, NULL, NULL, NULL,
+		                       "vpn_uuid", ui_data->vpn_uuid,
+		                       NULL);
 	}
 	g_hash_table_insert (ui_data->secrets, g_strdup ("save_passwords"), enabled);
 }
@@ -1466,9 +1438,9 @@ static void connect_host(auth_ui_data *ui_data)
 	ui_data->cancelled = FALSE;
 	ui_data->getting_cookie = TRUE;
 
-	g_mutex_lock (ui_data->form_mutex);
+	g_mutex_lock (&ui_data->form_mutex);
 	ui_data->form_retval = NULL;
-	g_mutex_unlock (ui_data->form_mutex);
+	g_mutex_unlock (&ui_data->form_mutex);
 
 	ssl_box_clear(ui_data);
 	gtk_widget_show(ui_data->getting_form_label);
@@ -1497,13 +1469,8 @@ static void connect_host(auth_ui_data *ui_data)
 	g_hash_table_insert (ui_data->success_secrets, g_strdup("lasthost"),
 			     g_strdup(host->hostname));
 
-#if GLIB_CHECK_VERSION(2,31,0)
 	thread = g_thread_new("obtain_cookie", (GThreadFunc)obtain_cookie, ui_data);
-#else
-	thread = g_thread_create((GThreadFunc)obtain_cookie, ui_data,
-				 FALSE, NULL);
-#endif
-	(void)thread;
+	g_thread_unref(thread);
 }
 
 
@@ -1536,10 +1503,10 @@ static void dialog_response (GtkDialog *dialog, int response, auth_ui_data *ui_d
 		ssl_box_clear(ui_data);
 		if (ui_data->getting_cookie)
 			gtk_widget_show (ui_data->getting_form_label);
-		g_mutex_lock (ui_data->form_mutex);
+		g_mutex_lock (&ui_data->form_mutex);
 		ui_data->form_retval = GINT_TO_POINTER(response);
-		g_cond_signal (ui_data->form_retval_changed);
-		g_mutex_unlock (ui_data->form_mutex);
+		g_cond_signal (&ui_data->form_retval_changed);
+		g_mutex_unlock (&ui_data->form_mutex);
 		break;
 	case GTK_RESPONSE_CLOSE:
 		gtk_main_quit();
@@ -1577,20 +1544,12 @@ static void build_main_dialog(auth_ui_data *ui_data)
 				 G_CALLBACK(gtk_main_quit), NULL);
 	g_free(title);
 
-#if GTK_CHECK_VERSION(3,1,6)
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
-#else
-	vbox = gtk_vbox_new(FALSE, 8);
-#endif
 	gtk_box_pack_start(GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (ui_data->dialog))), vbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
 	gtk_widget_show(vbox);
 
-#if GTK_CHECK_VERSION(3,1,6)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
-#else
-	hbox = gtk_hbox_new(FALSE, 4);
-#endif
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
@@ -1624,11 +1583,7 @@ static void build_main_dialog(auth_ui_data *ui_data)
 	gtk_widget_set_size_request(frame, -1, -1);
 	gtk_widget_show(frame);
 
-#if GTK_CHECK_VERSION(3,1,6)
 	frame_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
-#else
-	frame_box = gtk_vbox_new(FALSE, 4);
-#endif
 	gtk_container_set_border_width(GTK_CONTAINER(frame_box), 8);
 	gtk_container_add(GTK_CONTAINER(frame), frame_box);
 	gtk_widget_show(frame_box);
@@ -1642,19 +1597,11 @@ static void build_main_dialog(auth_ui_data *ui_data)
 	gtk_widget_set_sensitive(ui_data->getting_form_label, FALSE);
 	gtk_box_pack_start(GTK_BOX(frame_box), ui_data->getting_form_label, FALSE, FALSE, 0);
 
-#if GTK_CHECK_VERSION(3,1,6)
 	ui_data->ssl_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
-#else
-	ui_data->ssl_box = gtk_vbox_new(FALSE, 4);
-#endif
 	gtk_box_pack_start(GTK_BOX(frame_box), ui_data->ssl_box, FALSE, FALSE, 0);
 	gtk_widget_show(ui_data->ssl_box);
 
-#if GTK_CHECK_VERSION(3,1,6)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-#else
-	hbox = gtk_hbox_new (FALSE, 6);
-#endif
 	gtk_box_pack_end(GTK_BOX(frame_box), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
@@ -1711,21 +1658,10 @@ static auth_ui_data *init_ui_data (char *vpn_name, GHashTable *options, GHashTab
 	ui_data->retval = 1;
 
 	ui_data->form_entries = g_queue_new();
-#if GLIB_CHECK_VERSION(2,31,0)
-	ui_data->form_mutex = &ui_data->_gmutex;
-	ui_data->form_retval_changed = &ui_data->_gconds[0];
-	ui_data->form_shown_changed = &ui_data->_gconds[1];
-	ui_data->cert_response_changed = &ui_data->_gconds[2];
-	g_mutex_init(ui_data->form_mutex);
-	g_cond_init(ui_data->form_retval_changed);
-	g_cond_init(ui_data->form_shown_changed);
-	g_cond_init(ui_data->cert_response_changed);
-#else
-	ui_data->form_mutex = g_mutex_new();
-	ui_data->form_retval_changed = g_cond_new();
-	ui_data->form_shown_changed = g_cond_new();
-	ui_data->cert_response_changed = g_cond_new();
-#endif
+	g_mutex_init(&ui_data->form_mutex);
+	g_cond_init(&ui_data->form_retval_changed);
+	g_cond_init(&ui_data->form_shown_changed);
+	g_cond_init(&ui_data->cert_response_changed);
 	ui_data->vpn_name = vpn_name;
 	ui_data->vpn_uuid = vpn_uuid;
 	ui_data->options = options;
@@ -1858,9 +1794,6 @@ int main (int argc, char **argv)
 		return 1;
 	}
 
-#if !GLIB_CHECK_VERSION(2,31,0)
-	g_thread_init (NULL);
-#endif
 	gtk_init(0, NULL);
 
 	_ui_data = init_ui_data(vpn_name, options, secrets, vpn_uuid);
