@@ -95,6 +95,26 @@ typedef struct {
 #define COL_AUTH_PAGE 1
 #define COL_AUTH_TYPE 2
 
+/************** import/export **************/
+
+typedef enum {
+	NM_OPENCONNECT_IMPORT_EXPORT_ERROR_UNKNOWN = 0,
+	NM_OPENCONNECT_IMPORT_EXPORT_ERROR_NOT_OPENCONNECT,
+	NM_OPENCONNECT_IMPORT_EXPORT_ERROR_BAD_DATA,
+} NMOpenconnectImportError;
+
+#define NM_OPENCONNECT_IMPORT_EXPORT_ERROR nm_openconnect_import_export_error_quark ()
+
+static GQuark
+nm_openconnect_import_export_error_quark (void)
+{
+	static GQuark quark = 0;
+
+	if (G_UNLIKELY (quark == 0))
+		quark = g_quark_from_static_string ("nm-openconnect-import-export-error-quark");
+	return quark;
+}
+
 static NMConnection *
 import (NMVpnPluginUiInterface *iface, const char *path, GError **error)
 {
@@ -110,8 +130,12 @@ import (NMVpnPluginUiInterface *iface, const char *path, GError **error)
 	keyfile = g_key_file_new ();
 	flags = G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS;
 
-	if (!g_key_file_load_from_file (keyfile, path, flags, error)) {
-		g_set_error (error, 0, 0, "does not look like a %s VPN connection (parse failed)", OPENCONNECT_PLUGIN_NAME);
+	if (!g_key_file_load_from_file (keyfile, path, flags, NULL)) {
+		g_set_error (error,
+		             NM_OPENCONNECT_IMPORT_EXPORT_ERROR,
+		             NM_OPENCONNECT_IMPORT_EXPORT_ERROR_NOT_OPENCONNECT,
+		             "does not look like a %s VPN connection (parse failed)",
+		             OPENCONNECT_PLUGIN_NAME);
 		return NULL;
 	}
 
@@ -131,7 +155,11 @@ import (NMVpnPluginUiInterface *iface, const char *path, GError **error)
 	if (buf) {
 		nm_setting_vpn_add_data_item (s_vpn, NM_OPENCONNECT_KEY_GATEWAY, buf);
 	} else {
-		g_set_error (error, 0, 0, "does not look like a %s VPN connection (no Host)", OPENCONNECT_PLUGIN_NAME);
+		g_set_error (error,
+		             NM_OPENCONNECT_IMPORT_EXPORT_ERROR,
+		             NM_OPENCONNECT_IMPORT_EXPORT_ERROR_BAD_DATA,
+		             "does not look like a %s VPN connection (no Host)",
+		             OPENCONNECT_PLUGIN_NAME);
 		g_object_unref (connection);
 		return NULL;
 	}
@@ -215,7 +243,10 @@ export (NMVpnPluginUiInterface *iface,
 
 	f = fopen (path, "w");
 	if (!f) {
-		g_set_error (error, 0, 0, "could not open file for writing");
+		g_set_error_literal (error,
+		                     NM_OPENCONNECT_IMPORT_EXPORT_ERROR,
+		                     NM_OPENCONNECT_IMPORT_EXPORT_ERROR_UNKNOWN,
+		                     "could not open file for writing");
 		return FALSE;
 	}
 
@@ -227,7 +258,10 @@ export (NMVpnPluginUiInterface *iface,
 	if (value && strlen (value))
 		gateway = value;
 	else {
-		g_set_error (error, 0, 0, "connection was incomplete (missing gateway)");
+		g_set_error_literal (error,
+		                     NM_OPENCONNECT_IMPORT_EXPORT_ERROR,
+		                     NM_OPENCONNECT_IMPORT_EXPORT_ERROR_BAD_DATA,
+		                     "connection was incomplete (missing gateway)");
 		goto done;
 	}
 
